@@ -328,7 +328,7 @@ def test_secure_write_win32():
 
     def check_user_only_permissions(fname):
         # Windows has it's own permissions ACL patterns
-        username = os.environ["USERNAME"]
+        username = os.environ["USERNAME"].lower()
         permissions = fetch_win32_permissions(fname)
         print(permissions) # for easier debugging
         assert username in permissions
